/// <reference types="node" />
/// <reference types="node" />
export type MatchingResult = MatchingResultSuccess | MatchingResultRequestMismatch | MatchingResultRequestNotFound | MatchingResultMissingRequest | MatchingResultPlugin;
export type MatchingResultSuccess = {
    type: 'request-match';
};
export type MatchingResultRequestMismatch = {
    type: 'request-mismatch';
    method: string;
    path: string;
    mismatches: Mismatch[];
};
export type MatchingResultRequestNotFound = {
    type: 'request-not-found';
    method: string;
    path: string;
    request: RequestMismatch;
};
export type MatchingResultMissingRequest = {
    type: 'missing-request';
    method: string;
    path: string;
    request: RequestMismatch;
};
export type MatchingResultPlugin = {
    error: string;
    path?: string;
    mismatches: PluginContentMismatch[];
};
export type Mismatch = MethodMismatch | PathMismatch | StatusMismatch | QueryMismatch | HeaderMismatch | BodyTypeMismatch | BodyMismatch | MetadataMismatch | PluginContentMismatch;
export type MethodMismatch = {
    type: 'MethodMismatch';
    expected: string;
    actual: string;
};
export type PathMismatch = {
    type: 'PathMismatch';
    expected: string;
    actual: string;
    mismatch: string;
};
export type StatusMismatch = {
    type: 'StatusMismatch';
    expected: string;
    actual: string;
    mismatch: string;
};
export type QueryMismatch = {
    type: 'QueryMismatch';
    parameter: string;
    expected: string;
    actual: string;
    mismatch: string;
};
export type HeaderMismatch = {
    type: 'HeaderMismatch';
    key: string;
    expected: string;
    actual: string;
    mismatch: string;
};
export type BodyTypeMismatch = {
    type: 'BodyTypeMismatch';
    expected: string;
    actual: string;
    mismatch: string;
    expectedBody?: string;
    actualBody?: string;
};
export type BodyMismatch = {
    type: 'BodyMismatch';
    path: string;
    expected?: string;
    actual?: string;
    mismatch: string;
};
export type MetadataMismatch = {
    type: 'MetadataMismatch';
    key: string;
    expected: string;
    actual: string;
    mismatch: string;
};
export type RequestMismatch = {
    method?: string;
    path?: string;
    headers?: Record<string, Array<string>>;
    query?: Record<string, Array<string>>;
    body?: string;
};
export declare type PluginContentMismatch = {
    path: string;
    expected?: string;
    actual?: string;
    mismatch: string;
    diff?: string;
};
export type PluginInteraction = RequestPluginInteraction & ResponsePluginInteraction & RequestResponsePluginInteraction;
export type RequestPluginInteraction = {
    withPluginRequestInteractionContents: (contentType: string, contents: string) => boolean;
};
export type ResponsePluginInteraction = {
    withPluginResponseInteractionContents: (contentType: string, contents: string) => boolean;
};
export type RequestResponsePluginInteraction = {
    withPluginRequestResponseInteractionContents: (contentType: string, contents: string) => boolean;
};
export type PluginPact = {
    addPlugin: (plugin: string, version: string) => void;
    cleanupPlugins: () => void;
    cleanupMockServer: (port: number) => boolean;
};
export type ConsumerInteraction = PluginInteraction & {
    uponReceiving: (description: string) => boolean;
    given: (state: string) => boolean;
    givenWithParam: (state: string, name: string, value: string) => boolean;
    givenWithParams: (state: string, params: string) => boolean;
    withRequest: (method: string, path: string) => boolean;
    withQuery: (name: string, index: number, value: string) => boolean;
    withStatus: (status: number) => boolean;
    withRequestHeader: (name: string, index: number, value: string) => boolean;
    withRequestBody: (body: string, contentType: string) => boolean;
    withRequestBinaryBody: (body: Buffer, contentType: string) => boolean;
    withRequestMultipartBody: (contentType: string, filename: string, mimePartName: string) => boolean;
    withResponseHeader: (name: string, index: number, value: string) => boolean;
    withResponseBody: (body: string, contentType: string) => boolean;
    withResponseBinaryBody: (body: Buffer, contentType: string) => boolean;
    withResponseMultipartBody: (contentType: string, filename: string, mimePartName: string) => boolean;
};
export type ConsumerPact = PluginPact & {
    newInteraction: (description: string) => ConsumerInteraction;
    newAsynchronousMessage: (description: string) => AsynchronousMessage;
    newSynchronousMessage: (description: string) => SynchronousMessage;
    pactffiCreateMockServerForTransport: (address: string, transport: string, config: string, port?: number) => number;
    createMockServer: (address: string, port?: number, tls?: boolean) => number;
    mockServerMismatches: (port: number) => MatchingResult[];
    cleanupMockServer: (port: number) => boolean;
    writePactFile: (dir: string, merge?: boolean) => void;
    writePactFileForPluginServer: (port: number, dir: string, merge?: boolean) => void;
    mockServerMatchedSuccessfully: (port: number) => boolean;
    addMetadata: (namespace: string, name: string, value: string) => boolean;
};
export type AsynchronousMessage = RequestPluginInteraction & {
    given: (state: string) => void;
    givenWithParam: (state: string, name: string, value: string) => void;
    givenWithParams: (state: string, params: string) => void;
    expectsToReceive: (description: string) => void;
    withMetadata: (name: string, value: string) => void;
    withContents: (body: string, contentType: string) => void;
    withBinaryContents: (body: Buffer, contentType: string) => void;
    reifyMessage: () => string;
};
export type ConsumerMessage = AsynchronousMessage;
export type SynchronousMessage = PluginInteraction & {
    given: (state: string) => void;
    givenWithParam: (state: string, name: string, value: string) => void;
    givenWithParams: (state: string, params: string) => void;
    withMetadata: (name: string, value: string) => void;
    withRequestContents: (body: string, contentType: string) => void;
    withResponseContents: (body: string, contentType: string) => void;
    withRequestBinaryContents: (body: Buffer, contentType: string) => void;
    withResponseBinaryContents: (body: Buffer, contentType: string) => void;
};
export type ConsumerMessagePact = PluginPact & {
    newMessage: (description: string) => AsynchronousMessage;
    newAsynchronousMessage: (description: string) => AsynchronousMessage;
    newSynchronousMessage: (description: string) => SynchronousMessage;
    pactffiCreateMockServerForTransport: (address: string, transport: string, config: string, port?: number) => number;
    writePactFile: (dir: string, merge?: boolean) => void;
    writePactFileForPluginServer: (port: number, dir: string, merge?: boolean) => void;
    addMetadata: (namespace: string, name: string, value: string) => boolean;
    mockServerMismatches: (port: number) => MatchingResult[];
    mockServerMatchedSuccessfully: (port: number) => boolean;
};
